.. _spkg_sphinx_inline_tabs:

sphinx_inline_tabs: Add inline tabbed content to your Sphinx documentation
==========================================================================

Description
-----------

Add inline tabbed content to your Sphinx documentation

License
-------

Upstream Contact
----------------

https://pypi.org/project/sphinx-inline-tabs/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pip`
- :ref:`spkg_sphinx`

Version Information
-------------------

package-version.txt::

    2023.4.21

version_requirements.txt::

    sphinx-inline-tabs

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install sphinx-inline-tabs

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sphinx_inline_tabs

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install sphinx-inline-tabs


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
